# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_roast_scm_global_optspecs
	string join \n C/changesgenerate= A/changesauthor= e/changesemail= changesoutfile= set-version= set-name= U/git-repository-url= E/exclude= revision= versionrewriteregex= versionrewritepattern= depth= is-temporary= f/outfile= d/outdir= r/reproducible= g/ignore-git= I/ignore-hidden= c/compression= h/help V/version
end

function __fish_roast_scm_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_roast_scm_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_roast_scm_using_subcommand
	set -l cmd (__fish_roast_scm_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c roast-scm -n "__fish_roast_scm_needs_command" -s C -l changesgenerate -d 'Whether to generate or update a changelog file or not.' -r -f -a "true\t''
false\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s A -l changesauthor -d 'Author to include during the changelog generation.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s e -l changesemail -d 'Email of author to include during the changelog generation.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l changesoutfile -d 'Whether to specify a path to the changes file. Otherwise, it is the current directory and the filename is the same filename prefix of the generated tarball e.g. `source.tar.xz` will have `source.changes` file. If file exists, it prepends the newest changes to the top-most part of the text file.' -r -F
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l set-version -d 'Whether to hard code the version or not. Set it to hard code one, otherwise, it will use the generated version internally.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l set-name -d 'Whether to hard code the name or not. Set it to hard code one, otherwise, it will use the generated name internally.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s U -l git-repository-url -d 'Remote URL to the git repository.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s E -l exclude -d 'Additional paths such as files or directories from within target repository\'s work directory to exclude when generating the archive.' -r -F
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l revision -d 'Revision or tag. It can also be a specific commit hash or branch. Supports <https://git-scm.com/docs/git-rev-parse.html#_specifying_revisions>.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l versionrewriteregex -d 'Pass a regex with capture groups. Required by `versionrewritepattern` flag. Each capture group is labelled through increments of 1.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l versionrewritepattern -d 'Pass a pattern from the capture groups from `versionrewriteregex` flag.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l depth -d 'The depth of cloning the repository.' -r
complete -c roast-scm -n "__fish_roast_scm_needs_command" -l is-temporary -d 'Whether the cloned repository should be deleted or not after the operation.' -r -f -a "true\t''
false\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s f -l outfile -d 'Output file of the generated archive with path. If not provided, attempts to write the filename based on project name and revision based on <https://en.opensuse.org/openSUSE:Package_versioning_guidelines>.' -r -F
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s d -l outdir -d 'Output path of the generated archive.' -r -F
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s r -l reproducible -d 'Allow reproducibility for Reproducible Builds.' -r -f -a "true\t''
false\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s g -l ignore-git -d 'Whether to ignore git related metadata, files and directories.' -r -f -a "true\t''
false\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s I -l ignore-hidden -d 'Whether to ignore hidden directories and files or what we call dotfiles. Does not affect `--ignore-git`.' -r -f -a "true\t''
false\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s c -l compression -d 'Compression to use.' -r -f -a "gz\t''
xz\t''
zst\t''
zstd\t''
bz2\t''
not\t''"
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c roast-scm -n "__fish_roast_scm_needs_command" -s V -l version -d 'Print version'
complete -c roast-scm -n "__fish_roast_scm_needs_command" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c roast-scm -n "__fish_roast_scm_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c roast-scm -n "__fish_roast_scm_using_subcommand generate-completions-for" -s h -l help -d 'Print help'
complete -c roast-scm -n "__fish_roast_scm_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "generate-completions-for" -d 'Generate shell completions'
complete -c roast-scm -n "__fish_roast_scm_using_subcommand help; and not __fish_seen_subcommand_from generate-completions-for help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
